@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Acme::rafl::Everywhere;
 {
-  $Acme::rafl::Everywhere::VERSION = '0.006';
+  $Acme::rafl::Everywhere::VERSION = '0.007';
 }
 # ABSTRACT: rafl is so everywhere, he has his own Acme module!
 
@@ -32,6 +32,7 @@ my @default_facts = (
   q{rafl is so everywhere, he can patch your code even before you push it!},
   q{rafl is so everywhere, he caused an integer overflow in every Airline's mileage system!},
   q{rafl is so everywhere, there's a saved seat for him in every conference in the world!},
+  q{rafl is so everywhere, there's a DuckDuckGo.com "!rafl" bang syntax},
 );
 
 sub new {
@@ -62,7 +63,7 @@ Acme::rafl::Everywhere - rafl is so everywhere, he has his own Acme module!
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -86,8 +87,12 @@ L<Moose>, L<MooseX::Declare>, L<Catalyst>, L<Dist::Zilla>, L<signatures>,
 L<KiokuDB>, L<Gtk2>, Perl core, MetaCPAN and GSoC are just I<some> of the
 projects he's involved in.  
 
-There is proof for at least one fact noted by this distribution:
-http://t.co/jcne0k4p, taken at YAPC::EU 2012.
+There is proof for at least one fact noted by this distribution, taken at
+YAPC::EU 2012.
+
+=for html <img src="http://cdn.memegenerator.net/instances/400x/28135704.jpg" />
+
+=for html <a href="http://t.co/jcne0k4p"><img src="https://pbs.twimg.com/media/A1D_IQqCMAERsHA.jpg" /></a>
 
 =head1 CONTRIBUTERS
 
@@ -99,7 +104,7 @@ not exist without the help of these tireless hard-working lead investigators:
 
 =item * Breno (garu) G. de Oliveira
 
-=item * Sawyer X
+=item * Damien Krotkine
 
 =item * Toby Inkster
 
@@ -124,6 +129,12 @@ more than welcome to add any new info.
 
 To C<rafl> for being everywhere. :)
 
+=head1 SEE ALSO
+
+http://piuparts.debian.org/squeeze/maintainer/r/rafl@debian.org.html
+
+https://metacpan.org/author/FLORA
+
 =head1 AUTHOR
 
 Sawyer X <xsawyerx@cpan.org>
